import React from 'react';
import purebem from 'purebem';
import { pgettext } from '@billogram/lang';
import reactInterpolate from '@billogram/react-interpolate';
import './FoundationTextarea.scss';

function noop() {}

export default /*#__PURE__*/React.forwardRef(function FoundationTextarea(_ref, ref) {
  var _ref$autoFocus = _ref.autoFocus,
      autoFocus = _ref$autoFocus === void 0 ? false : _ref$autoFocus,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      _ref$hasErrors = _ref.hasErrors,
      errors = _ref$hasErrors === void 0 ? false : _ref$hasErrors,
      _ref$maxLength = _ref.maxLength,
      maxLength = _ref$maxLength === void 0 ? void 0 : _ref$maxLength,
      _ref$onChange = _ref.onChange,
      onChange = _ref$onChange === void 0 ? noop : _ref$onChange,
      _ref$placeholder = _ref.placeholder,
      placeholder = _ref$placeholder === void 0 ? '' : _ref$placeholder,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value;
  var block = purebem('foundation-textarea');
  var textareaRef = React.useRef(null);
  React.useImperativeHandle(ref, function () {
    return {
      focus: function focus() {
        if (textareaRef.current !== null) {
          textareaRef.current.focus();
        }
      },
      select: function select() {
        if (textareaRef.current !== null) {
          textareaRef.current.select();
        }
      }
    };
  });
  var handleChange = React.useCallback(function (evt) {
    onChange(evt.target.value);
  }, [onChange]);
  var remainingCharacters = typeof maxLength === 'number' && maxLength >= 0 ? maxLength - value.length : null;
  return /*#__PURE__*/React.createElement("div", {
    className: block()
  }, /*#__PURE__*/React.createElement("textarea", {
    autoFocus: autoFocus,
    className: block('input', {
      disabled: disabled,
      errors: errors
    }),
    disabled: disabled,
    maxLength: maxLength,
    onChange: handleChange,
    placeholder: placeholder,
    ref: textareaRef,
    value: value
  }), remainingCharacters !== null ? /*#__PURE__*/React.createElement("div", {
    className: block('remaining-characters')
  }, reactInterpolate(pgettext('foundation-remaining-characters', 'Label--characters-remaining[%(remaining)s]'), {
    remaining: remainingCharacters
  })) : null);
});
//# sourceMappingURL=FoundationTextarea.js.map